@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Email::Address;
-# ABSTRACT: (DEPRECATED) RFC 2822 Address Parsing and Creation
-$Email::Address::VERSION = '1.911';
+# ABSTRACT: RFC 2822 Address Parsing and Creation
+$Email::Address::VERSION = '1.912';
 our $COMMENT_NEST_LEVEL ||= 1;
 our $STRINGIFY          ||= 'format';
 our $COLLAPSE_SPACES      = 1 unless defined $COLLAPSE_SPACES; # I miss //=
@@ -18,19 +18,22 @@ our $COLLAPSE_SPACES      = 1 unless defined $COLLAPSE_SPACES; # I miss //=
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod B<ACHTUNG!> This module has a vulnerability
-#pod (L<CVE-2015-7686|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-7686>)
-#pod which allows remote attackers to cause denial of service.   In other words,
-#pod sometimes it takes way too long to process certain kinds of input.  Maybe
-#pod someday this will be fixed.  Until then, use
-#pod L<B<Email::Address::XS>|Email::Address::XS> instead which has backward
-#pod compatible API.
-#pod
 #pod This class implements a regex-based RFC 2822 parser that locates email
 #pod addresses in strings and returns a list of C<Email::Address> objects found.
 #pod Alternatively you may construct objects manually. The goal of this software is
 #pod to be correct, and very very fast.
 #pod
+#pod Version 1.909 and earlier of this module had vulnerabilies
+#pod (L<CVE-2015-7686|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-7686>)
+#pod and (L<CVE-2015-12558|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12558>)
+#pod which allowed specially constructed email to cause a denial of service. The
+#pod reported vulnerabilities and some other pathalogical cases (meaning they really
+#pod shouldn't occur in normal email) have been addressed in version 1.910 and newer.
+#pod If you're running version 1.909 or older, you should update!
+#pod
+#pod Alternatively, you could switch to L<B<Email::Address::XS>|Email::Address::XS>
+#pod which has a backward compatible API.
+#pod
 #pod =cut
 
 my $CTL            = q{\x00-\x1F\x7F};
@@ -161,12 +164,6 @@ sub __dump {
 #pod     q[me@local, Casey <me@local>, "Casey" <me@local> (West)]
 #pod   );
 #pod
-#pod B<ACHTUNG!> This is where that vulnerability mentioned above lies.  Do not use
-#pod this method with untrusted user input.
-#pod
-#pod Use method L<parse from the Email::Address::XS module|Email::Address::XS/parse>
-#pod instead.
-#pod
 #pod This method returns a list of C<Email::Address> objects it finds in the input
 #pod string.  B<Please note> that it returns a list, and expects that it may find
 #pod multiple addresses.  The behavior in scalar context is undefined.
@@ -552,11 +549,11 @@ use overload '""' => 'as_string', fallback => 1;
 
 =head1 NAME
 
-Email::Address - (DEPRECATED) RFC 2822 Address Parsing and Creation
+Email::Address - RFC 2822 Address Parsing and Creation
 
 =head1 VERSION
 
-version 1.911
+version 1.912
 
 =head1 SYNOPSIS
 
@@ -569,19 +566,22 @@ version 1.911
 
 =head1 DESCRIPTION
 
-B<ACHTUNG!> This module has a vulnerability
-(L<CVE-2015-7686|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-7686>)
-which allows remote attackers to cause denial of service.   In other words,
-sometimes it takes way too long to process certain kinds of input.  Maybe
-someday this will be fixed.  Until then, use
-L<B<Email::Address::XS>|Email::Address::XS> instead which has backward
-compatible API.
-
 This class implements a regex-based RFC 2822 parser that locates email
 addresses in strings and returns a list of C<Email::Address> objects found.
 Alternatively you may construct objects manually. The goal of this software is
 to be correct, and very very fast.
 
+Version 1.909 and earlier of this module had vulnerabilies
+(L<CVE-2015-7686|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2015-7686>)
+and (L<CVE-2015-12558|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12558>)
+which allowed specially constructed email to cause a denial of service. The
+reported vulnerabilities and some other pathalogical cases (meaning they really
+shouldn't occur in normal email) have been addressed in version 1.910 and newer.
+If you're running version 1.909 or older, you should update!
+
+Alternatively, you could switch to L<B<Email::Address::XS>|Email::Address::XS>
+which has a backward compatible API.
+
 =head2 Package Variables
 
 B<ACHTUNG!>  Email isn't easy (if even possible) to parse with a regex, I<at
@@ -637,12 +637,6 @@ following comment.
     q[me@local, Casey <me@local>, "Casey" <me@local> (West)]
   );
 
-B<ACHTUNG!> This is where that vulnerability mentioned above lies.  Do not use
-this method with untrusted user input.
-
-Use method L<parse from the Email::Address::XS module|Email::Address::XS/parse>
-instead.
-
 This method returns a list of C<Email::Address> objects it finds in the input
 string.  B<Please note> that it returns a list, and expects that it may find
 multiple addresses.  The behavior in scalar context is undefined.
@@ -837,7 +831,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Vandiver David Golden Steinbrunner Glenn Fowler Kevin Falcone Pali Ruslan Zakirov sunnavy William Yardley
+=for stopwords Alex Vandiver David Golden Steinbrunner Glenn Fowler Jim Brandt Kevin Falcone Pali Ruslan Zakirov sunnavy William Yardley
 
 =over 4
 
@@ -859,6 +853,10 @@ Glenn Fowler <cebjyre@cpan.org>
 
 =item *
 
+Jim Brandt <jbrandt@bestpractical.com>
+
+=item *
+
 Kevin Falcone <kevin@jibsheet.com>
 
 =item *
